nagios_host 'nephsap.org' do
	options 'use' => 'noping-host-https',
		'alias' => 'nephro',
		'address' => 'nephsap.org',
		'contact_groups' => 'cs_escalation,nephro',
		'notes' => 'Nephsap Live Site',
		'notes_url' => 'https://safari.atlassian.net/wiki/spaces/ASN/pages/577568779/NEPHRO+-+Server+Setup'
end
#------------------------------------------------------------------------------------
# HOMEPAGE
# Checks the homepage of the live Nephsap site and checks for the string 'nephSAP'.
#
# Node-specific: NO, Pager-level: YES
#------------------------------------------------------------------------------------
nagios_service 'nephsap.org-Live Homepage' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'nephsap.org',
		'display_name' => 'Live Homepage',
		'check_command' => 'https_content_check_basic_auth!nephro:nephro2018!/!"nephSAP"!10!20!',
		'notes' => 'Nephsap Live Site',
		'notes_url' => 'https://nephsap.org/'
end
#------------------------------------------------------------------------------------
# HOMEPAGE (NODE 1)
# Checks the homepage of the live Nephsap site on the first web node and checks for the string 'nephSAP'.
#
# Node-specific: YES, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'nephsap.org-Live Homepage: web-16' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'nephsap.org',
		'display_name' => 'Live Homepage: web-16',
		'check_command' => 'https_content_check_basic_auth_single_node!nephro:nephro2018!/!"nephSAP"!10!20!nephro-web-live16!web-16!',
		'contact_groups' => 'admins_email_only,nephro',
		'notes' => 'Nephsap Live Site: web-16',
		'notes_url' => 'https://nephsap.org/'
end
#------------------------------------------------------------------------------------
# HOMEPAGE (NODE 2)
# Checks the homepage of the live Nephsap site on the second web node and checks for the string 'nephSAP'.
#
# Node-specific: YES, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'nephsap.org-Live Homepage: web-17' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'nephsap.org',
		'display_name' => 'Live Homepage: web-17',
		'check_command' => 'https_content_check_basic_auth_single_node!nephro:nephro2018!/!"nephSAP"!10!20!nephro-web-live17!web-17!',
		'contact_groups' => 'admins_email_only,nephro',
		'notes' => 'Nephsap Live Site: web-17',
		'notes_url' => 'https://nephsap.org/'
end
#------------------------------------------------------------------------------------
# HOMEPAGE (NODE 3 BOT)
# Checks the homepage of the live Nephsap site on the second web node and checks for the string 'nephSAP'.
#
# Node-specific: YES, Pager-level: NO
#------------------------------------------------------------------------------------
# nagios_service 'nephsap.org-Live Homepage: web-24' do
# 	options 'use' => 'sbo-service-pf',
# 		'host_name' => 'nephsap.org',
# 		'display_name' => 'Live Homepage: web-24',
# 		'check_command' => 'https_content_check_basic_auth_single_node_bot!nephro:nephro2018!/!"nephSAP"!10!20!nephro-web-live24!web-24!',
# 		'contact_groups' => 'admins_email_only,nephro',
# 		'notes' => 'Nephsap Live Site: web-24',
# 		'notes_url' => 'https://nephsap.org/'
#end
#------------------------------------------------------------------------------------
# SEARCH
# Checks the search page of the live Nephsap site and checks for the string 'Browse'.
#
# Node-specific: NO, Pager-level: YES
#------------------------------------------------------------------------------------
nagios_service 'nephsap.org-Live Search' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'nephsap.org',
		'display_name' => 'Live Search',
		'check_command' => 'https_content_check_basic_auth!nephro:nephro2018!/browse?level=parent!Browse!10!20!',
		'notes' => 'Nephsap Live Site',
		'notes_url' => 'https://nephsap.org/browse?level=parent'
end
#------------------------------------------------------------------------------------
# VIEW
# Checks a content view page of the live nephro site for the book at the URL
# /view/journals/nephsap/18/5/article-p259.xml.  The title of this journal is "International Journal of Sport Nutrition and Exercise Equipoise".  This check
# looks for the string 'Equipoise' in the response.
#
# Node-specific: NO, Pager-level: YES
#------------------------------------------------------------------------------------
nagios_service 'nephsap.org-Live Content View' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'nephsap.org',
		'display_name' => 'Live Content View',
		'check_command' => 'https_content_check_basic_auth!nephro:nephro2018!/view/journals/nephsap/18/5/article-p259.xml!Equipoise!10!20!',
		'notes' => 'Nephsap Live Site',
		'notes_url' => 'https://nephsap.org/view/journals/nephsap/18/5/article-p259.xml'
end
#------------------------------------------------------------------------------------
# LOADER
# Checks a loader login page and looks for the string 'Login' in the response.
#
# Node-specific: NO, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'nephsap.org-Production Loader' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'nephsap.org',
		'display_name' => 'Production Loader',
		'check_command' => 'check_loader_auth!admin.nephsap.org!/login!nephro:nephro2018!"Nephro Production Management Portal"!20!10',
		'contact_groups' => 'admins_email_only,nephro',
		'notes' => 'Nephsap Live Loader',
		'notes_url' => 'https://admin.nephsap.org/login'
end
#------------------------------------------------------------------------------------
# STAGING
# Checks the staging site homepage and looks for the string 'nephSAP' in the response.
#
# Node-specific: NO, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'nephsap.org-Staging Homepage' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'nephsap.org',
		'display_name' => 'Staging Homepage',
		'check_command' => 'check_staging_auth!staging.nephsap.org!nephro:nephro2018!"nephSAP"!20!10',
		'contact_groups' => 'admins_email_only,nephro',
		'notes' => 'Nephsap Staging Site',
		'notes_url' => 'https://staging.nephsap.org/'
end
#------------------------------------------------------------------------------------
# AMX
# Checks the production amx homepage and looks for the string 'Nephsap' in the response.
#
# Node-specific: NO, Pager-level: NO
#------------------------------------------------------------------------------------
# nagios_service 'nephsap.org-Production AMX' do
# 	options 'use' => 'sbo-service-pf',
# 		'host_name' => 'nephsap.org',
# 		'display_name' => 'Production AMX',
# 		'check_command' => 'check_loader_auth!ams.nephsap.org!/login!nephro:nephro2018!AMS!20!10',
# 		'contact_groups' => 'admins_email_only,nephro',
# 		'notes' => 'Nephsap AMX',
# 		'notes_url' => 'https://ams.nephsap.org/login'
# end
#------------------------------------------------------------------------------------
# FAIL OPEN
# Checks the production homepage and makes sure we're not in fail open by checking
# that the string "Provisional Account" is NOT in the page.
#
# Node-specific: NO, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'nephsap.org-Live Site Fail Open' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'nephsap.org',
		'display_name' => 'Live Site Fail Open',
		'check_command' => 'http_negate_content_check_basic_auth!nephsap.org!nephro:nephro2018!"provisional account"',
		'contact_groups' => 'admins_email_only,nephro',
		'notes' => 'Nephsap Live Site Failopen',
		'notes_url' => 'https://nephsap.org/'
end
